@@ -30,7 +30,7 @@ hilight_source = function(x, format, options) {
 
 highlight_header = function() {
   set_header(highlight.extra = paste(c(
-    sprintf('\\let\\hl%s\\hlstd', c('esc', 'pps', 'lin')),
+    sprintf('\\let\\hl%s\\hldef', c('esc', 'pps', 'lin')),
     sprintf('\\let\\hl%s\\hlcom', c('slc', 'ppc'))
   ), collapse = ' '))
 }
