@@ -313,7 +313,7 @@ process_file = function(text, output) {
         if (tangle) process_tangle(group) else process_group(group),
         error = function(e) if (xfun::pkg_available('rlang', '1.0.0')) rlang::entrace(e)
       ),
-      function(e, loc) {
+      function(loc) {
         setwd(wd)
         write_utf8(res, output %n% stdout())
         paste0('\nQuitting from lines ', loc)
@@ -443,7 +443,7 @@ knit_log = new_defaults()  # knitr log for errors, warnings and messages
 #' output of the code chunk (code, messages, text output, and plots, etc.) after
 #' all statements in the code chunk have been evaluated, and will sew these
 #' pieces of output together into a character vector.
-#' @param x Output from \code{evaluate::\link{evaluate}()}.
+#' @param x Output from \code{evaluate::\link[evaluate]{evaluate}()}.
 #' @param options A list of chunk options used to control output.
 #' @param ... Other arguments to pass to methods.
 #' @export
